| Title: | Dataset-JSON Example Files |
|---|---|
| Description: | An R data package providing a set of Dataset-JSON files comprising SDTM and ADaM datasets. Examples are originally from: <https://github.com/cdisc-org/DataExchange-DatasetJson>. |
| Authors: | Ramiro Magno [aut, cre] (ORCID: <https://orcid.org/0000-0001-5226-3441>), Pattern Institute [cph, fnd] |
| Maintainer: | Ramiro Magno <[email protected]> |
| License: | CC BY 4.0 |
| Version: | 0.0.1 |
| Built: | 2026-05-17 05:20:06 UTC |
| Source: | https://github.com/ramiromagno/dataset.json.examples |
example_path() retrieves the local path to the bundled Dataset-JSON example
files. These files are compressed with xz.
example_path(name = NULL)example_path(name = NULL)
name |
The name of Dataset-JSON example. Run |
A character vector of absolute paths to Dataset-JSON example files.
example_path("ae") example_path("adsl")example_path("ae") example_path("adsl")
unxz() decompresses a xz file into a new file.
unxz(from, to)unxz(from, to)
from |
A path to a xz file. |
to |
A path to a new file (uncompressed). |
This function is ran for its side effect of creating a new file and
returns its path, i.e. to.
newfile <- file.path(tempdir(), "ae.json") unxz(from = example_path("ae"), to = newfile)newfile <- file.path(tempdir(), "ae.json") unxz(from = example_path("ae"), to = newfile)